@@ -12,7 +12,7 @@ import os
 import streamlit as st
 
 from paddleocr import PaddleOCR
-from appzoo.utils.ocr_utils import *
+from appzoo.utils.image_utils import *
 from appzoo.utils.streamlit_utils import *
 
 ocr = PaddleOCR(use_angle_cls=True, lang="ch")
